# CHANGELOG



## v0.8.2 (2024-01-08)

### Fix

* fix: Fixes in first commit (#60)

fix: Fixes in first commit

fix: Fixes in first commit ([`e69d0d7`](https://github.com/MartinBernstorff/herbarium/commit/e69d0d77f91632bea76fc4adcb68a0921d8a6632))

* fix: Fixes in first commit ([`8341b40`](https://github.com/MartinBernstorff/herbarium/commit/8341b4002f4ce350952942c2cf19a29a90815f0c))

### Style

* style: lint ([`249025e`](https://github.com/MartinBernstorff/herbarium/commit/249025ea8555b34554a7ae3844e5a5db206c5ae6))

### Unknown

* cli: fix emoji handling in prompt

Fixes #{issue.entity_id} ([`edd4e74`](https://github.com/MartinBernstorff/herbarium/commit/edd4e74a34c8601b8997084a6d5127b7183fbb64))

* dev: remove redundant ruff target version ([`bf7f6a4`](https://github.com/MartinBernstorff/herbarium/commit/bf7f6a463d85aae7f3a2b1b1a1014c95f42984a2))

* cli: fix emoji handling in prompt (#59)

cli: fix emoji handling in prompt

Fixes #{issue.entity_id}

misc. ([`79392c0`](https://github.com/MartinBernstorff/herbarium/commit/79392c07ba9cb5187327a4513be7778c7e0f61f0))

* misc. ([`1ff09a2`](https://github.com/MartinBernstorff/herbarium/commit/1ff09a2aa12ef7f7e6ec7cfdb9409b10d1b5ac0a))

* dev: remove redundant ruff target version (#63)

dev: remove redundant ruff target version

dev: remove redundant ruff target version ([`3737c4a`](https://github.com/MartinBernstorff/herbarium/commit/3737c4a597e0cc1c40101bc588304d11ca38853b))

* dev: remove redundant ruff target version ([`3149656`](https://github.com/MartinBernstorff/herbarium/commit/31496564ce8afe8be1d3e679faa88bef4be0efb4))

* dev: remove redundant ruff target version ([`0acebcb`](https://github.com/MartinBernstorff/herbarium/commit/0acebcb24fc75f6bb6e5bf52e848fef2bac08c5a))


## v0.8.1 (2024-01-08)

### Fix

* fix: prettier subprocess handling (#57)

fix: prettier subprocess handling

Fixes #{issue.entity_id}

misc. ([`2faa5a2`](https://github.com/MartinBernstorff/herbarium/commit/2faa5a2fc05ca27116099a4761aa83eaf23e8bcf))

* fix: prettier subprocess handling

Fixes #{issue.entity_id} ([`5e4204e`](https://github.com/MartinBernstorff/herbarium/commit/5e4204eed04344cb8ae8db6a01f9fba6c1da0ec0))

### Unknown

* misc. ([`d2edd50`](https://github.com/MartinBernstorff/herbarium/commit/d2edd5065dc6a95ce66aa16292a2c21a52c78828))


## v0.8.0 (2024-01-08)

### Feature

* feat: simplify prompt (#56)

feat: simplify prompt

misc. ([`c017abd`](https://github.com/MartinBernstorff/herbarium/commit/c017abdd64406dc93ca283c3e2846cdc3dfc875d))

* feat: simplify prompt ([`92c1885`](https://github.com/MartinBernstorff/herbarium/commit/92c18850cddbe9d107f6759eed17b008e12cb17a))

### Unknown

* misc. ([`649fe4a`](https://github.com/MartinBernstorff/herbarium/commit/649fe4af6410923a945ba9855045d22b96c326e9))

* misc. (#55) ([`8c91f5c`](https://github.com/MartinBernstorff/herbarium/commit/8c91f5cc75573a84caa45e4e70b17606577d2158))

* misc. ([`f1656a7`](https://github.com/MartinBernstorff/herbarium/commit/f1656a7493273eb93fe867a546ecf599d8247a77))


## v0.7.0 (2024-01-08)

### Feature

* feat: allow manual creation (#53)

feat: allow manual creation

Fixes #20

misc.

misc.

misc.

misc.

misc.

misc. ([`aa7f404`](https://github.com/MartinBernstorff/herbarium/commit/aa7f404b2bbbd59965ea10f3ab92b0561bc83468))

* feat: allow manual creation

Fixes #20 ([`8050c4b`](https://github.com/MartinBernstorff/herbarium/commit/8050c4b7a10f29817dec260100b58f2a2c4a296c))

### Style

* style: linting ([`2f095e1`](https://github.com/MartinBernstorff/herbarium/commit/2f095e1cfb478ddcc9117b9814a034bfbba1bf43))

### Unknown

* misc. ([`ba0a034`](https://github.com/MartinBernstorff/herbarium/commit/ba0a034bfce09b875d3fbcfffa65e78f88113e97))

* misc. ([`d3c75fe`](https://github.com/MartinBernstorff/herbarium/commit/d3c75fec3ad59a2a160ca0f2236f6a943d1cae9f))

* misc. ([`4bccccb`](https://github.com/MartinBernstorff/herbarium/commit/4bccccbd3ba923d8e00c0465a4c8fd07d72a0312))

* misc. ([`13b5811`](https://github.com/MartinBernstorff/herbarium/commit/13b5811285d6e4d66e9574036c79fe14786861be))

* misc. ([`9dd20aa`](https://github.com/MartinBernstorff/herbarium/commit/9dd20aa8fb5909ecc7899ab17dc9b0841c59d163))

* misc. ([`88e8b32`](https://github.com/MartinBernstorff/herbarium/commit/88e8b32c4fecd0af366c87bef521c0d0b0ece832))

* misc. ([`345ec2f`](https://github.com/MartinBernstorff/herbarium/commit/345ec2fc3b379f2016097b48ceebb69976450d23))


## v0.6.0 (2024-01-08)

### Feature

* feat: cleaner issue title parsing (#48) ([`da985b9`](https://github.com/MartinBernstorff/herbarium/commit/da985b91103e8421ca653a448122936e8e0d05ea))

* feat: cleaner issue title parsing

Fixes #16 ([`76821cf`](https://github.com/MartinBernstorff/herbarium/commit/76821cfb833bf16e2f80df519b025a14b3d29304))

### Unknown

* cli: present refresh option when finding issues (#50) ([`3d69629`](https://github.com/MartinBernstorff/herbarium/commit/3d69629d79115793bc490bb4a95552aad238fafe))

* misc. ([`a4300f9`](https://github.com/MartinBernstorff/herbarium/commit/a4300f9d9779cfa9e7566850a32e65a33d737bbf))

* cli: present refresh option when finding issues

Fixes #49 ([`3a6f020`](https://github.com/MartinBernstorff/herbarium/commit/3a6f020c5e274b30e6e3a72dc54ae2cd6a5c3df7))

* misc. ([`a8b9623`](https://github.com/MartinBernstorff/herbarium/commit/a8b96233560dd2d4e92f6d860b221056a1dc507a))


## v0.5.0 (2024-01-08)

### Feature

* feat: pretty error message if no issues assigned (#47)

feat: pretty error message if no issues assigned

Fixes #29

misc.

fix: types ([`84f501e`](https://github.com/MartinBernstorff/herbarium/commit/84f501eb5f27788f546b96809d843b02be8fbaf0))

* feat: pretty error message if no issues assigned

Fixes #29 ([`6087659`](https://github.com/MartinBernstorff/herbarium/commit/608765985b3afb2c82fe85e26e7c07933637148e))

### Fix

* fix: types ([`50ef8e8`](https://github.com/MartinBernstorff/herbarium/commit/50ef8e8ea9465dfc270425921923fc15148f7aee))

### Unknown

* misc. ([`6c195ba`](https://github.com/MartinBernstorff/herbarium/commit/6c195ba50e21f5b9f55e937216b9be266c9ac699))


## v0.4.1 (2024-01-08)

### Ci

* ci: run tests on prs against any branch (#39) ([`e21f947`](https://github.com/MartinBernstorff/herbarium/commit/e21f9477d183d65fd1d7701e691d1c46882a15ef))

* ci: run tests on prs against any branch ([`28c6035`](https://github.com/MartinBernstorff/herbarium/commit/28c603591f7b3037a610a8261c67a14f449aab39))

### Fix

* fix: prettier log

Fixes #35 ([`8e149ba`](https://github.com/MartinBernstorff/herbarium/commit/8e149ba4aa166e439138f027894b41a909798fe2))

### Unknown

* cli: reverse log output (#45)

cli: reverse log output

Fixes #44

cli: reverse log output

Fixes #44 ([`a4faa4b`](https://github.com/MartinBernstorff/herbarium/commit/a4faa4ba49ef31d6e2dad7b95e275b32909b0f72))

* cli: reverse log output

Fixes #44 ([`3d68811`](https://github.com/MartinBernstorff/herbarium/commit/3d6881183f9af53a875e67c9a2521fb9c960b58a))

* misc. ([`5213f14`](https://github.com/MartinBernstorff/herbarium/commit/5213f1453aa956db3bc17f349bdcda8c5b2d22c6))

* misc. ([`428c6ae`](https://github.com/MartinBernstorff/herbarium/commit/428c6aeeb101c1554f5515278829564ad2e73883))

* cli: simplify stack submit animations (#43)

cli: simplify stack submit animations

Fixes #42

misc. ([`d2e44b6`](https://github.com/MartinBernstorff/herbarium/commit/d2e44b60dbe2b96a5c4a7b56d3b0022c321de8a5))

* misc. ([`834beb9`](https://github.com/MartinBernstorff/herbarium/commit/834beb96486e0aee8efabe881543cc462af9db4f))

* dev: submit with automerge (#41)

dev: submit with automerge

Fixes #40

misc. ([`1657a46`](https://github.com/MartinBernstorff/herbarium/commit/1657a46d5e56d4855554458010c1da773e026451))

* misc. ([`0b43842`](https://github.com/MartinBernstorff/herbarium/commit/0b43842cf145ba29421fd2521cf8cc24b23ef326))

* dev: submit with automerge

Fixes #40 ([`144e52c`](https://github.com/MartinBernstorff/herbarium/commit/144e52ca324fc353070af6f2926fc74d7eb1e848))


## v0.4.0 (2024-01-08)

### Feature

* feat: delete unused branches on submit (#37)

feat: delete unused branches on submit

Fixes #30

misc.

fix: even prettier logs ([`45d6a50`](https://github.com/MartinBernstorff/herbarium/commit/45d6a50f0d7238790d0b657594987c1b678c648d))


## v0.3.1 (2024-01-08)

### Fix

* fix: prettier log (#36)

fix: prettier log

Fixes #35

fix: prettier log

Fixes #35 ([`4482f2c`](https://github.com/MartinBernstorff/herbarium/commit/4482f2c9dda485cc006ab5b299f412525a1eabc5))


## v0.3.0 (2024-01-08)

### Feature

* feat: newline after submitting stack to get log pretty (#34)

feat: newline after submitting stack to get log pretty

Fixes #31

misc. ([`99de3de`](https://github.com/MartinBernstorff/herbarium/commit/99de3ded14a272fe85e2e2a68a0e7ce555305a3f))

* feat: make automerge a command-line argument (#33)

Fixes #32 ([`6ecac7f`](https://github.com/MartinBernstorff/herbarium/commit/6ecac7f1ae9a2829d2696b0af8e226997e476ecc))


## v0.2.0 (2024-01-08)

### Feature

* feat: support python &gt;=3.9 (#28)

feat: support python &gt;=3.9

Fixes #27

feat: support python &gt;=3.9

Fixes #27

misc.

misc.

misc. ([`61d9402`](https://github.com/MartinBernstorff/herbarium/commit/61d9402f6601fbe85c6a6c2bec04d6211a4f8007))


## v0.1.0 (2024-01-07)

### Ci

* ci: fix release pipeline ([`e28c77c`](https://github.com/MartinBernstorff/herbarium/commit/e28c77ca98d35733ae3309265bc8d73d6ca9afe5))

* ci: setup release to pypi (#24)

ci: setup release to pypi

Fixes #21

ci: setup release to pypi

Fixes #21

tests: get tests running

misc.

ci: setup release.yml ([`3106412`](https://github.com/MartinBernstorff/herbarium/commit/3106412b885c832f12feaa75c1dc5d16c0088292))

### Feature

* feat: add GithubIssueService

Fixes #8. ([`c2939c3`](https://github.com/MartinBernstorff/herbarium/commit/c2939c3e12247e255293837076643fd6ae811451))

### Unknown

* misc. ([`79f4f2d`](https://github.com/MartinBernstorff/herbarium/commit/79f4f2df5ae0960c0ef15fb96f18ea30eb1eafc5))

* misc. ([`3ad9517`](https://github.com/MartinBernstorff/herbarium/commit/3ad95172a8addfe265cca73cef58c9ee69e5eae2))

* dev: create github cli dir on devcontainer init ([`58c40e6`](https://github.com/MartinBernstorff/herbarium/commit/58c40e6f34e14a1192a6ff177a53f5f417825ab8))

* misc. ([`8de39ac`](https://github.com/MartinBernstorff/herbarium/commit/8de39ac6cb6d45ab0c7066fa18553a4b7a2bade3))

* $feat: pretty cli animations with typer/rich (#23)

$feat: pretty cli animations with typer/rich

Fixes #13

$feat: pretty cli animations with typer/rich

Fixes #13

misc.

misc. ([`830040c`](https://github.com/MartinBernstorff/herbarium/commit/830040c8ec929215791ec495332ebefcc1eca7bd))

* dev: clean up gitignore (#22)

Fixes #19 ([`a58c808`](https://github.com/MartinBernstorff/herbarium/commit/a58c808497b99ee460ad38e840ed658a1a2d93f9))

* $fix: misc. types (#17)

$fix: misc. types

Fixes #14

$fix: misc. types

Fixes #14

refactor: cleanup

misc. ([`4342005`](https://github.com/MartinBernstorff/herbarium/commit/43420050f810d0bad2e6b85708d6d4449140e1c4))

* misc. ([`9d6b6de`](https://github.com/MartinBernstorff/herbarium/commit/9d6b6ded5bd4a56f0fa2f4731c65ef02d4e32ad1))

* Update README.md (#12) ([`f2d76a0`](https://github.com/MartinBernstorff/herbarium/commit/f2d76a05372650b192b47205bca60a3803549762))

* first commit ([`5af600e`](https://github.com/MartinBernstorff/herbarium/commit/5af600e2b31b082b6785271c806243553de5e7bf))
